@@ -25,7 +25,6 @@
 #include <QStandardItemModel>
 
 #include <QAction>
-#include <QIcon>
 #include <QUrl>
 #include <KXmlGuiWindow>
 
@@ -132,7 +131,7 @@ private:
     QModelIndex getCurrentParent();
 
     // Expand to, select and focus a new item from the given parameters
-    void focusNewItem(QModelIndex parent, QStandardItem *item);
+    void focusNewItem(const QModelIndex &parent, QStandardItem *item);
 
     void setShortcut(const QKeySequence &sequence);
 
